@@ -1,3 +1,7 @@
+__all__ = [
+    "get_setting"
+]
+
 def get_setting(name: str, default):
     from django.conf import settings
     
